@@ -1,3 +1,4 @@
+#' @import MatchIt
 SEsubclass <- R6::R6Class(
   "SEexact",
   inherit = SEstimator,
@@ -7,8 +8,8 @@ SEsubclass <- R6::R6Class(
 
     initialize = function(target.obj, source.obj,
                           weighting_method="glm",
-                          confounders_sampling_name){
-      super$initialize(target.obj, source.obj,weighting_method,confounders_sampling_name)
+                          selection_predictors){
+      super$initialize(target.obj, source.obj,weighting_method,selection_predictors)
       self$weighting_method <- weighting_method
     }
   ),
