@@ -8,13 +8,13 @@ TEstimator_Synthetic <- R6::R6Class(
       self$estimates$ATE$est <- estimates$ATE_mean
       self$estimates$ATE$se <- estimates$ATE_se
       self$estimates$CATE <- estimates$CATE_mean_se
-      private$confounders_treatment_name <- vars_name$confounders_treatment_name
+      private$outcome_predictors <- vars_name$outcome_predictors
       # self$data should be joint distribution of confounders with sample size
       if(data.public){
         self$data <- data
       } else {
         self$data <- data %>%
-          group_by(across(all_of(private$confounders_treatment_name))) %>%
+          group_by(across(all_of(private$outcome_predictors))) %>%
           summarise(size=n())
       }
       self$data$id <- seq(dim(self$data)[1])
@@ -29,7 +29,7 @@ TEstimator_Synthetic <- R6::R6Class(
       #browser()
       joint_var_internal <-
         self$data %>%
-        group_by(across(all_of(c(private$confounders_treatment_name)))) %>%
+        group_by(across(all_of(c(private$outcome_predictors)))) %>%
         summarise(count=n())
       joint_var_internal <- as.data.frame(joint_var_internal)
       return(joint_var_internal)
